==> haskell-one-liner-1.0-92-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-one-liner.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 one-liner
version:              1.0
visibility:           public
id:                   one-liner-1.0-7sJk2uJS4kX1Kfis93Ld9L
key:                  one-liner-1.0-7sJk2uJS4kX1Kfis93Ld9L
license:              BSD-3-Clause
maintainer:           sjoerd@w3future.com
author:               Sjoerd Visscher, Xia Li-yao
homepage:             https://github.com/sjoerdvisscher/one-liner
synopsis:             Constraint-based generics
description:
    Write short and concise generic instances of type classes.
    one-liner is particularly useful for writing default
    implementations of type class methods.

category:             Generics
abi:                  51053c20a2f20471231bcd74def6e32f
exposed:              True
exposed-modules:
    Generics.OneLiner Generics.OneLiner.Binary
    Generics.OneLiner.Classes Generics.OneLiner.Internal
    Generics.OneLiner.Internal.Unary

import-dirs:          /usr/lib/ghc-8.10.4/site-local/one-liner-1.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/one-liner-1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/one-liner-1.0
hs-libraries:         HSone-liner-1.0-7sJk2uJS4kX1Kfis93Ld9L
depends:
    base-4.14.1.0 bifunctors-5.5.10-5RJEo2qbSYFClbX7yYPmwd
    contravariant-1.5.3-7koBfVZf7s8G3BlROnwJJd ghc-prim-0.6.1
    profunctors-5.6.2-N0awPHz8gV42wPtfoka2E
    tagged-0.8.6.1-A3E8I7zg2qBFE9O5vQsg6C transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-one-liner/html/one-liner.haddock
haddock-html:         /usr/share/doc/haskell-one-liner/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-one-liner-1.0-93-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-one-liner.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 one-liner
version:              1.0
visibility:           public
id:                   one-liner-1.0-2MCjdZPAotw3V9YbRW8IjA
key:                  one-liner-1.0-2MCjdZPAotw3V9YbRW8IjA
license:              BSD-3-Clause
maintainer:           sjoerd@w3future.com
author:               Sjoerd Visscher, Xia Li-yao
homepage:             https://github.com/sjoerdvisscher/one-liner
synopsis:             Constraint-based generics
description:
    Write short and concise generic instances of type classes.
    one-liner is particularly useful for writing default
    implementations of type class methods.

category:             Generics
abi:                  853f7bb8cbdf63c961e5a6ab1d50d9ac
exposed:              True
exposed-modules:
    Generics.OneLiner Generics.OneLiner.Binary
    Generics.OneLiner.Classes Generics.OneLiner.Internal
    Generics.OneLiner.Internal.Unary

import-dirs:          /usr/lib/ghc-8.10.4/site-local/one-liner-1.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/one-liner-1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/one-liner-1.0
hs-libraries:         HSone-liner-1.0-2MCjdZPAotw3V9YbRW8IjA
depends:
    base-4.14.1.0 bifunctors-5.5.10-7Yin4ScrU49DV2YTBmGbdt
    contravariant-1.5.3-7koBfVZf7s8G3BlROnwJJd ghc-prim-0.6.1
    profunctors-5.6.2-GERPk2aKNhL7iEdQbm0u7N
    tagged-0.8.6.1-A3E8I7zg2qBFE9O5vQsg6C transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-one-liner/html/one-liner.haddock
haddock-html:         /usr/share/doc/haskell-one-liner/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
